==> tecfy_corev2_package-1.1.35.tar.gz: lib/models/entity/property_text_multi_lang.model.dart <==
part of tecfy_corev2_client_package;

class PropertyTextMultiLang extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyTextMultiLang(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Text,
            valueType: ValueTypes.Text,
            isRequired: isRequired);

  PropertyTextMultiLang.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && (!(data is Map) || (isRequired && data.length == 0))) {
      print(isRequired);
      print(data is String);
      print(data);
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('XXText Value Required')} ($name)");
    }

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Max Length exceped')} ($name)");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Min Length not reached')} ($name)");

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    // return Text(
    //     data[dbName]?[LocalConfigService.languagePrefix.toLowerCase()]
    //             .toString() ??
    //         '',
    //     style: textStyle);
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
    return MapService.getValue(
                data, dbName)[LocalConfigService.languagePrefix.toLowerCase()]
            ?.toString() ??
        '';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null &&
        MapService.getValue(data, dbName).toString().isNotEmpty) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = defaultString;
      MapService.updateValue(data, dbName, defaultString);
      return true;
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.40.tar.gz: lib/models/entity/property_text_multi_lang.model.dart <==
part of tecfy_corev2_client_package;

class PropertyTextMultiLang extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyTextMultiLang(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Text,
            valueType: ValueTypes.Text,
            isRequired: isRequired);

  PropertyTextMultiLang.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Text Value Required')} ($name)");

    if (data != null && (!(data is Map) || (isRequired && data.length == 0))) {
      print(isRequired);
      print(data is String);
      print(data);
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('XXText Value Required')} ($name)");
    }

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Max Length exceped')} ($name)");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false,
          message: "${AppLocale.translate('Min Length not reached')} ($name)");

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    // return Text(
    //     data[dbName]?[LocalConfigService.languagePrefix.toLowerCase()]
    //             .toString() ??
    //         '',
    //     style: textStyle);
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value in text
  String getDisplayText(Map<String, dynamic> data) {
// try {
//   print(data);
    return (MapService.getValue(data, dbName)
                    as Map)[LocalConfigService.languagePrefix.toLowerCase()] !=
                '' &&
            (MapService.getValue(data, dbName)
                    as Map)[LocalConfigService.languagePrefix.toLowerCase()] !=
                null
        ? (MapService.getValue(data, dbName)
            as Map)[LocalConfigService.languagePrefix.toLowerCase()]
        : (MapService.getValue(data, dbName) as Map)[
            LocalConfigService.languagePrefix.toLowerCase() == 'ar'
                ? 'en'
                : 'ar'];
    // } catch (e) {}
    // return '';
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null &&
        MapService.getValue(data, dbName).toString().isNotEmpty) return false;
    if (defaultString?.isNotEmpty ?? false) {
      // data[dbName] = defaultString;
      MapService.updateValue(data, dbName, defaultString);
      return true;
    }
    return false;
  }
}
